<?php

namespace Amazingcat\Labels\Controller\Adminhtml\CatalogRule;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Controller\ResultInterface;
use Magento\Framework\Filesystem;
use Magento\MediaStorage\Model\File\UploaderFactory;

/**
 * Class UploadLabel
 * @package Amazingcat\Labels\Controller\Adminhtml\CatalogRule
 */
class UploadLabel extends Action
{
    /**
     * @var Filesystem\Directory\WriteInterface
     */
    protected $mediaDirectory;

    /**
     * @var UploaderFactory
     */
    protected $fileUploaderFactory;

    /**
     * Upload constructor.
     * @param Context $context
     * @param Filesystem $fileSystem
     * @param UploaderFactory $fileUploaderFactory
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    public function __construct(
        Context $context,
        FileSystem $fileSystem,
        UploaderFactory $fileUploaderFactory
    ) {
        $this->mediaDirectory = $fileSystem->getDirectoryWrite(DirectoryList::MEDIA);
        $this->fileUploaderFactory = $fileUploaderFactory;
        parent::__construct($context);
    }

    /**
     * @return ResponseInterface|ResultInterface
     */
    public function execute()
    {
        try {
            $uploader = $this->fileUploaderFactory
                ->create(['fileId' => 'rule_label'])
                ->setAllowCreateFolders(true);

            $uploader->setAllowedExtensions(['jpg', 'ico', 'png', 'gif']);
            $uploader->setAllowRenameFiles(true);
            $path = $this->mediaDirectory->getAbsolutePath('rulelabels/');

            $this->_eventManager->dispatch('amazingcat_labels_rule_label_beforesave', ['uploader' => $uploader]);

            $result = $uploader->save($path);

            $this->_eventManager->dispatch('amazingcat_labels_rule_label_aftersave', ['uploader' => $result ]);

            $result['url'] = '/pub/media/rulelabels/' . $result['file'];
        } catch (\Exception $e) {
            $result = [
                'error'     => $e->getMessage(),
                'errorcode' => $e->getCode(),
            ];
        }

        return $this->resultFactory->create(ResultFactory::TYPE_JSON)->setData($result);
    }
}
