<?php

namespace Amazingcat\Labels\Model;

use Amazingcat\Labels\Api\Data\DefaultLabelInterface;
use Amazingcat\Labels\Model\ResourceModel\DefaultLabel as DefaultLabelResource;
use Magento\Framework\Data\Collection\AbstractDb;
use Magento\Framework\Model\AbstractModel;
use Magento\Framework\Model\Context;
use Magento\Framework\Model\ResourceModel\AbstractResource;
use Magento\Framework\Registry;

/**
 * Class DefaultLabel
 * @package Amazingcat\Labels\Model
 */
class DefaultLabel extends AbstractModel implements DefaultLabelInterface
{
    /**
     * @var ResourceModel\DefaultLabel
     */
    protected $collectionFactory;

    /**
     * @var string
     */
    protected $_eventPrefix = 'amazingcat_default_Label';

    /**
     * DefaultLabel constructor.
     * @param DefaultLabelResource $collectionFactory
     * @param Context $context
     * @param Registry $registry
     * @param AbstractResource|null $resource
     * @param AbstractDb|null $resourceCollection
     * @param array $data
     */
    public function __construct(
        DefaultLabelResource $collectionFactory,
        Context $context,
        Registry $registry,
        AbstractResource $resource = null,
        AbstractDb $resourceCollection = null,
        array $data = []
    ) {
        $this->collectionFactory = $collectionFactory;

        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Default Constructor.
     */
    protected function _construct()
    {
        $this->_init(ResourceModel\DefaultLabel::class);
    }

    /**
     * @return \Magento\Framework\DataObject[]
     */
    public function getDefaultLabels()
    {
        $categories = $this->collectionFactory->create()->addFieldToFilter('id', $this->getId())->getItems();

        return $categories;
    }

    /**
     * @return string
     */
    public function getDefaultLabelsTable()
    {
        return $this->_eventPrefix;
    }

    /**
     * @param $id
     * @return mixed
     */
    public function setId($id)
    {
        $this->setData('id', $id);
        return $this;
    }

    /**
     * @return mixed
     */
    public function getId()
    {
        return $this->getData('id');
    }

    /**
     * @param $name
     * @return mixed
     */
    public function setName($name)
    {
        $this->setData('name', $name);
        return $this;
    }

    /**
     * @return mixed
     */
    public function getName()
    {
        return $this->getData('name');
    }

    /**
     * @param $position
     * @return mixed
     */
    public function setPosition($position)
    {
        $this->setData('position', $position);
        return $this;
    }

    /**
     * @return mixed
     */
    public function getPosition()
    {
        return $this->getData('position');
    }

    /**
     * @param $imagePath
     * @return mixed
     */
    public function setImagePath($imagePath)
    {
        $this->setData('image_path', $imagePath);
        return $this;
    }

    /**
     * @return mixed
     */
    public function getImagePath()
    {
        return $this->getData('image_path');
    }
}
