<?php

namespace Amazingcat\Labels\Plugin\Model\Rule;

use Magento\CatalogRule\Model\Rule;
use Magento\CatalogRule\Model\Rule\DataProvider;
use Magento\CatalogRule\Model\ResourceModel\Rule\Collection;
use Magento\CatalogRule\Model\ResourceModel\Rule\CollectionFactory;
use Magento\Framework\App\Request\DataPersistorInterface;

class DataProviderPlugin
{
    /**
     * @var Collection
     */
    protected $collection;

    /**
     * @var array
     */
    protected $loadedData;

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * DataProviderPlugin constructor.
     * @param CollectionFactory $collectionFactory
     * @param DataPersistorInterface $dataPersistor
     */
    public function __construct(
        CollectionFactory $collectionFactory,
        DataPersistorInterface $dataPersistor
    ) {
        $this->collection = $collectionFactory->create();
        $this->dataPersistor = $dataPersistor;
    }

    /**
     * @param DataProvider $subject
     * @param $result
     * @return array
     */
    public function afterGetData(DataProvider $subject, $result)
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }

        $items = $this->collection->getItems();

        /** @var Rule $rule */
        foreach ($items as $rule) {
            $rule->load($rule->getId());
            $this->loadedData[$rule->getId()] = $rule->getData();

            if ($label = $rule->getData('rule_label')) {
                $image['rule_label'][0]['name'] =
                    explode(DIRECTORY_SEPARATOR, $label)[count(explode(DIRECTORY_SEPARATOR, $label)) - 1];
                $image['rule_label'][0]['file'] =
                    explode(DIRECTORY_SEPARATOR, $label)[count(explode(DIRECTORY_SEPARATOR, $label)) - 1];
                $image['rule_label'][0]['url'] = $label;
                $image['rule_label'][0]['path'] = $label;
                $image['rule_label'][0]['type'] = "image";
                $fd = $this->loadedData;
                $this->loadedData[$rule->getId()] = array_merge($fd[$rule->getId()], $image);
            }
        }

        $data = $this->dataPersistor->get('catalog_rule');

        if (!empty($data)) {
            $rule = $this->collection->getNewEmptyItem();
            $rule->setData($data);
            $this->loadedData[$rule->getId()] = $rule->getData();
            $this->dataPersistor->clear('catalog_rule');
        }

        return $this->loadedData;
    }
}
