<?php

namespace Amazingcat\Labels\Setup;

use Magento\Catalog\Model\Category\Attribute\Backend\Image;
use Magento\Catalog\Model\ResourceModel\Eav\Attribute;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;

/**
 * Class InstallData
 * @package Amazingcat\Labels\Setup
 */
class InstallData implements InstallDataInterface
{
    /**
     * @var EavSetupFactory
     */
    protected $eavSetupFactory;

    /**
     * InstallData constructor.
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(EavSetupFactory $eavSetupFactory)
    {
        $this->eavSetupFactory = $eavSetupFactory;
    }

    /**
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();
        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        $eavSetup
            ->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                'product_label',
                [
                    'group'                   => 'Product Details',
                    'type'                    => 'varchar',
                    'backend'                 => Image::class,
                    'label'                   => 'Product Label',
                    'input'                   => 'media_image',
                    'class'                   => '',
                    'global'                  => ScopedAttributeInterface::SCOPE_GLOBAL,
                    'visible'                 => true,
                    'required'                => false,
                    'user_defined'            => true,
                    'default'                 => '',
                    'searchable'              => false,
                    'filterable'              => false,
                    'comparable'              => false,
                    'visible_on_front'        => false,
                    'used_in_product_listing' => true,
                    'unique'                  => false,
                ]
            )
            ->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                'default_label',
                [
                    'type'       => 'varchar',
                    'label'      => 'Default Label',
                    'backend'    => 'Magento\Eav\Model\Entity\Attribute\Backend\ArrayBackend',
                    'input'      => 'select',
                    'source'     => 'Amazingcat\Labels\Model\Source\DefaultLabelSource',
                    'required'   => false,
                    'global'     => Attribute::SCOPE_STORE,
                    'order'      => 120,
                    'searchable' => false,
                    'filterable' => false,
                ]
            );

        $setup->endSetup();
    }
}
